@@ -1,7 +1,7 @@
 /*
  * libopenraw - libopenraw.h
  *
- * Copyright (C) 2005-2008 Hubert Figuiere
+ * Copyright (C) 2005-2016 Hubert Figuiere
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,11 +22,14 @@
  * @author Hubert Figuiere <hub@figuiere.net>
  */
 
-#ifndef __LIBOPENRAW_H__
-#define __LIBOPENRAW_H__
+#ifndef LIBOPENRAW_H_
+#define LIBOPENRAW_H_
+
+#include <libopenraw/prefix.h>
 
 #include <libopenraw/types.h>
 #include <libopenraw/consts.h>
+#include <libopenraw/cameraids.h>
 #include <libopenraw/io.h>
 #include <libopenraw/thumbnails.h>
 #include <libopenraw/rawdata.h>
@@ -34,15 +37,7 @@
 #include <libopenraw/rawfile.h>
 #include <libopenraw/debug.h>
 #include <libopenraw/demosaic.h>
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
-
-#ifdef __cplusplus
-}
-#endif
+#include <libopenraw/cfapattern.h>
+#include <libopenraw/metadata.h>
 
 #endif
