@@ -20,55 +20,72 @@
  */
 
 #include <assert.h>
-#include "bititerator.h"
+#include <algorithm>
+#include "bititerator.hpp"
 
 namespace OpenRaw {
 namespace Internals {
 
-BitIterator::BitIterator(const void * const p) :
-	m_p(static_cast<const uint8_t * const>(p)),
-	m_bitBuffer(0), m_bitsOnBuffer(0)
+BitIterator::BitIterator(const uint8_t * const p, size_t size)
+    : m_p(p)
+    , m_size(size)
+    , m_bitBuffer(0)
+    , m_bitsOnBuffer(0)
 
 {
 }
 
 void BitIterator::load(size_t numBits)
 {
-	size_t numBytes = (numBits + 7) / 8;
+    size_t numBytes = (numBits + 7) / 8;
 
-	//align the bits on the right
-	m_bitBuffer >>= (32 - m_bitsOnBuffer);
+    //align the bits on the right
+    m_bitBuffer >>= (32 - m_bitsOnBuffer);
 
-	m_bitsOnBuffer += 8 * numBytes;
+    m_bitsOnBuffer += 8 * numBytes;
 
-	//load the new bits from the right
-	for (size_t i = 0; i < numBytes; ++i) {
-		m_bitBuffer = (m_bitBuffer << 8) | *m_p;
-		++m_p;
-	}
+    //load the new bits from the right
+    for (size_t i = 0; i < numBytes && m_size > 0; ++i) {
+        m_bitBuffer = (m_bitBuffer << 8) | *m_p;
+        ++m_p;
+        m_size--;
+    }
 
-	//align the bits on the left
-	m_bitBuffer = m_bitBuffer << (32 - m_bitsOnBuffer);
+    //align the bits on the left
+    m_bitBuffer = m_bitBuffer << (32 - m_bitsOnBuffer);
 }
 
 uint32_t BitIterator::get(size_t n)
 {
-	assert(n <= 25);
+	uint32_t ret = peek(n);
 
-	if (n == 0)
-		return 0;
-
-	if (n > m_bitsOnBuffer)
-		load(n - m_bitsOnBuffer);
-
-	assert(n <= m_bitsOnBuffer);
-
-	uint32_t ret = m_bitBuffer >> (32 - n);
-	m_bitsOnBuffer -= n;
-	m_bitBuffer <<= n;
+	skip(n);
 
 	return ret;
 }
 
+uint32_t BitIterator::peek(size_t n)
+{
+	assert(n <= 25);
+	
+	if (n == 0)
+		return 0;
+	
+	if (n > m_bitsOnBuffer)
+		load(n - m_bitsOnBuffer);
+	
+	assert(n <= m_bitsOnBuffer);
+	
+	return m_bitBuffer >> (32 - n);
+}
+
+void BitIterator::skip(size_t n)
+{
+	size_t num_bits = std::min(n, m_bitsOnBuffer);
+	m_bitsOnBuffer -= num_bits;
+	m_bitBuffer <<= num_bits;
+}
+
+	
 }
 }
