@@ -1,7 +1,7 @@
 /*
  * libopenraw - ciffcontainer.cpp
  *
- * Copyright (C) 2006-2016 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -35,17 +35,45 @@ namespace CIFF {
 
 bool ImageSpec::readFrom(off_t offset, CIFFContainer *container)
 {
-    bool ret;
     auto file = container->file();
     file->seek(offset, SEEK_SET);
-    ret = container->readUInt32(file, imageWidth);
-    ret = container->readUInt32(file, imageHeight);
-    ret = container->readUInt32(file, pixelAspectRatio);
-    ret = container->readInt32(file, rotationAngle);
-    ret = container->readUInt32(file, componentBitDepth);
-    ret = container->readUInt32(file, colorBitDepth);
-    ret = container->readUInt32(file, colorBW);
-    return ret;
+
+    auto result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    imageWidth = result_u32.unwrap();
+    result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    imageHeight = result_u32.unwrap();
+    result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    pixelAspectRatio = result_u32.unwrap();
+    auto result_32 = container->readInt32(file);
+    if (result_32.empty()) {
+        return false;
+    }
+    rotationAngle = result_32.unwrap();
+    result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    componentBitDepth = result_u32.unwrap();
+    result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    colorBitDepth = result_u32.unwrap();
+    result_u32 = container->readUInt32(file);
+    if (result_u32.empty()) {
+        return false;
+    }
+    colorBW = result_u32.unwrap();
+    return true;
 }
 
 int32_t ImageSpec::exifOrientation() const
@@ -75,12 +103,23 @@ RecordEntry::RecordEntry()
 
 bool RecordEntry::readFrom(CIFFContainer *container)
 {
-    bool ret;
     auto file = container->file();
-    ret = container->readUInt16(file, typeCode);
-    ret = container->readUInt32(file, length);
-    ret = container->readUInt32(file, offset);
-    return ret;
+    auto result_16 = container->readUInt16(file);
+    if (result_16.empty()) {
+        return false;
+    }
+    typeCode = result_16.unwrap();
+    auto result_32 = container->readUInt32(file);
+    if (result_32.empty()) {
+        return false;
+    }
+    length = result_32.unwrap();
+    result_32 = container->readUInt32(file);
+    if (result_32.empty()) {
+        return false;
+    }
+    offset = result_32.unwrap();
+    return true;
 }
 
 size_t RecordEntry::fetchData(Heap* heap, void* buf, size_t size) const
@@ -96,8 +135,7 @@ Heap::Heap(off_t start, off_t length, CIFFContainer * _container)
       m_container(_container),
       m_records()
 {
-    Debug::Trace(DEBUG2) << "Heap @ " << start << " length = "
-                         << m_length << "\n";
+    LOGDBG2("Heap @ %ld length = %ld\n", start, m_length);
 }
 
 std::vector<RecordEntry> & Heap::records()
@@ -113,27 +151,30 @@ bool Heap::_loadRecords()
 {
     auto file = m_container->file();
     file->seek(m_start + m_length - 4, SEEK_SET);
-    int32_t record_offset;
-    bool ret = m_container->readInt32(file, record_offset);
 
-    if (ret) {
-        int16_t numRecords;
+    auto result = m_container->readInt32(file);
+
+    if (result.ok()) {
+        int32_t record_offset = result.unwrap();
 
         m_records.clear();
         file->seek(m_start + record_offset, SEEK_SET);
-        ret = m_container->readInt16(file, numRecords);
-        if (!ret) {
-            Trace(DEBUG1) << "read failed: " << ret << "\n";
+        auto result16 = m_container->readInt16(file);
+        if (result16.empty()) {
+            LOGDBG1("read numRecords failed\n");
+            return false;
         }
-        Trace(DEBUG2) << "numRecords " << numRecords << "\n";
-        int16_t i;
+        int16_t numRecords = result16.unwrap();
+        LOGDBG2("numRecords %d\n", numRecords);
+
         m_records.reserve(numRecords);
-        for (i = 0; i < numRecords; i++) {
+        for (int16_t i = 0; i < numRecords; i++) {
             m_records.push_back(RecordEntry());
             m_records.back().readFrom(m_container);
         }
+        return true;
     }
-    return ret;
+    return false;
 }
 
 
@@ -159,7 +200,11 @@ bool HeapFileHeader::readFrom(CIFFContainer *container)
             endian = RawContainer::ENDIAN_BIG;
         }
         container->setEndian(endian);
-        ret = container->readUInt32(file, headerLength);
+        auto result32 = container->readUInt32(file);
+        if (result32.ok()) {
+            headerLength = result32.unwrap();
+            ret = true;
+        }
         if (ret) {
             ret = (file->read(type, 4) == 4);
         }
@@ -167,7 +212,11 @@ bool HeapFileHeader::readFrom(CIFFContainer *container)
             ret = (file->read(subType, 4) == 4);
         }
         if (ret) {
-            ret = container->readUInt32(file, version);
+            result32 = container->readUInt32(file);
+            if (result32.ok()) {
+                version = result32.unwrap();
+                ret = true;
+            }
         }
     }
     return ret;
@@ -205,14 +254,14 @@ bool CIFFContainer::_loadHeap()
     if (m_endian != ENDIAN_NULL) {
         off_t heapLength = m_file->filesize() - m_hdr.headerLength;
 
-        Trace(DEBUG1) << "heap len " << heapLength << "\n";
+        LOGDBG1("heap len %ld\n", heapLength);
         m_heap = std::make_shared<CIFF::Heap>(m_hdr.headerLength,
                                               heapLength, this);
 
         ret = true;
     }
     else {
-        Trace(DEBUG1) << "Unknown endian\n";
+        LOGDBG1("Unknown endian\n");
     }
 
     return ret;
@@ -245,7 +294,7 @@ CIFF::Heap::Ref CIFFContainer::getImageProps()
                                      return e.isA(static_cast<uint16_t>(CIFF::TAG_IMAGEPROPS));
                                  });
         if (iter == records.end()) {
-            Trace(ERROR) << "Couldn't find the image properties.\n";
+            LOGERR("Couldn't find the image properties.\n");
             return CIFF::Heap::Ref();
         }
 
@@ -269,7 +318,7 @@ const CIFF::ImageSpec * CIFFContainer::getImageSpec()
                                      return e.isA(static_cast<uint16_t>(CIFF::TAG_IMAGEINFO));
                                  });
         if (iter == propsRecs.end()) {
-            Trace(ERROR) << "Couldn't find the image info.\n";
+            LOGERR("Couldn't find the image info.\n");
             return nullptr;
         }
         m_imagespec.readFrom(iter->offset + props->offset(), this);
@@ -292,7 +341,7 @@ const CIFF::Heap::Ref CIFFContainer::getCameraProps()
                                      return e.isA(static_cast<uint16_t>(CIFF::TAG_CAMERAOBJECT));
                                  });
         if (iter == propsRecs.end()) {
-            Trace(ERROR) << "Couldn't find the camera props.\n";
+            LOGERR("Couldn't find the camera props.\n");
             return CIFF::Heap::Ref();
         }
         m_cameraprops = std::make_shared<CIFF::Heap>(
