@@ -1,7 +1,8 @@
+/* -*- mode:c++; tab-width:4; c-basic-offset:4; indent-tabs-mode:nil; -*- */
 /*
  * libopenraw - cr2file.cpp
  *
- * Copyright (C) 2006-2017 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  * Copyright (C) 2008 Novell, Inc.
  *
  * This library is free software: you can redistribute it and/or
@@ -311,9 +312,11 @@ const IfdFile::camera_ids_t Cr2File::s_def[] = {
     { "Canon EOS 350D DIGITAL", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_350D) },
     { "Canon EOS DIGITAL REBEL XT",
       OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_XT) },
+    { "Canon EOS Kiss Digital N", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_KISS_DIGITAL_N) },
     { "Canon EOS 40D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_40D) },
     { "Canon EOS 400D DIGITAL", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_400D) },
     { "Canon EOS 450D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_450D) },
+    { "Canon EOS DIGITAL REBEL XSi", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_XSI) },
     { "Canon EOS 50D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_50D) },
     { "Canon EOS 500D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_500D) },
     { "Canon EOS 550D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_550D) },
@@ -329,11 +332,13 @@ const IfdFile::camera_ids_t Cr2File::s_def[] = {
     { "Canon EOS 760D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_760D) },
     { "Canon EOS 80D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_80D) },
     { "Canon EOS 800D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_800D) },
+    { "Canon EOS REBEL T1i", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T1I) },
     { "Canon EOS Rebel T5", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T5) },
     { "Canon EOS REBEL T5i", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T5I) },
     { "Canon EOS Rebel T6i", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T6I) },
     { "Canon EOS Rebel T6s", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T6S) },
     { "Canon EOS Rebel T6", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T6) },
+    { "Canon EOS Rebel T7i", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T7I) },
     { "Canon EOS 1000D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_1000D) },
     { "Canon EOS DIGITAL REBEL XS",
       OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_XS) },
@@ -351,10 +356,13 @@ const IfdFile::camera_ids_t Cr2File::s_def[] = {
     { "Canon EOS 6D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_6D) },
     { "Canon EOS 7D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_7D) },
     { "Canon EOS 7D Mark II", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_7DMKII) },
+    { "Canon EOS 77D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_77D) },
+    { "Canon EOS Kiss X3", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_KISS_X3) },
     { "Canon EOS M", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M) },
     { "Canon EOS M10", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M10) },
     { "Canon EOS M3", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M3) },
     { "Canon EOS M5", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M5) },
+    { "Canon EOS M6", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M6) },
     { "Canon PowerShot G9", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G9) },
     { "Canon PowerShot G10", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G10) },
     { "Canon PowerShot G11", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G11) },
@@ -408,56 +416,61 @@ IfdDir::Ref Cr2File::_locateMainIfd()
 {
     const IfdDir::Ref &_cfaIfd = cfaIfd();
     if (!_cfaIfd) {
-        Trace(DEBUG1) << "cfa IFD not found\n";
+        LOGDBG1("cfa IFD not found\n");
         return OR_ERROR_NOT_FOUND;
     }
 
-    Trace(DEBUG1) << "_getRawData()\n";
-    uint32_t offset = 0;
-    uint32_t byte_length = 0;
-    bool got_it;
-    got_it = _cfaIfd->getValue(IFD::EXIF_TAG_STRIP_OFFSETS, offset);
-    if (!got_it) {
-        Trace(DEBUG1) << "offset not found\n";
+    LOGDBG1("_getRawData()\n");
+
+    auto result = _cfaIfd->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_OFFSETS);
+    if (result.empty()) {
+        LOGDBG1("offset not found\n");
         return OR_ERROR_NOT_FOUND;
     }
-    got_it = _cfaIfd->getValue(IFD::EXIF_TAG_STRIP_BYTE_COUNTS, byte_length);
-    if (!got_it) {
-        Trace(DEBUG1) << "byte len not found\n";
+    uint32_t offset = result.unwrap();
+
+    result = _cfaIfd->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_BYTE_COUNTS);
+    if (result.empty()) {
+        LOGDBG1("byte len not found\n");
         return OR_ERROR_NOT_FOUND;
     }
+    uint32_t byte_length = result.unwrap();
+
     // get the "slicing", tag 0xc640 (3 SHORT)
     std::vector<uint16_t> slices;
     IfdEntry::Ref e = _cfaIfd->getEntry(IFD::CR2_TAG_SLICE);
     if (e) {
-        e->getArray(slices);
-        Trace(DEBUG1) << "Found slice entry " << slices << "\n";
+        auto result2 = e->getArray<uint16_t>();
+        if (result2.ok()) {
+            slices = result2.unwrap();
+            LOGDBG1("Found slice entry count %ld\n", slices.size());
+        }
     }
 
     const IfdDir::Ref &_exifIfd = exifIfd();
     if (!_exifIfd) {
-        Trace(ERROR) << "unable to find ExifIFD\n";
+        LOGERR("unable to find ExifIFD\n");
         return OR_ERROR_NOT_FOUND;
     }
 
-    uint16_t x, y;
-    x = 0;
-    y = 0;
-    got_it = _exifIfd->getValue(IFD::EXIF_TAG_PIXEL_X_DIMENSION, x);
-    if (!got_it) {
-      Trace(DEBUG1) << "X not found\n";
-      return OR_ERROR_NOT_FOUND;
+    auto result2 = _exifIfd->getValue<uint16_t>(IFD::EXIF_TAG_PIXEL_X_DIMENSION);
+    if (result2.empty()) {
+        LOGDBG1("X not found\n");
+        return OR_ERROR_NOT_FOUND;
     }
-    got_it = _exifIfd->getValue(IFD::EXIF_TAG_PIXEL_Y_DIMENSION, y);
-    if (!got_it) {
-      Trace(DEBUG1) << "Y not found\n";
-      return OR_ERROR_NOT_FOUND;
+    uint16_t x = result2.unwrap();
+
+    result2 = _exifIfd->getValue<uint16_t>(IFD::EXIF_TAG_PIXEL_Y_DIMENSION);
+    if (result2.empty()) {
+        LOGDBG1("Y not found\n");
+        return OR_ERROR_NOT_FOUND;
     }
+    uint16_t y = result2.unwrap();
 
     void *p = data.allocData(byte_length);
     size_t real_size = m_container->fetchData(p, offset, byte_length);
     if (real_size < byte_length) {
-      Trace(WARNING) << "Size mismatch for data: ignoring.\n";
+        LOGWARN("Size mismatch for data: ignoring.\n");
     }
     // they are not all RGGB.
     // but I don't seem to see where this is encoded.
@@ -466,8 +479,7 @@ IfdDir::Ref Cr2File::_locateMainIfd()
     data.setDataType(OR_DATA_TYPE_COMPRESSED_RAW);
     data.setDimensions(x, y);
 
-    Trace(DEBUG1) << "In size is " << data.width() << "x" << data.height()
-                  << "\n";
+    LOGDBG1("In size is %dx%d\n", data.width(), data.height());
     // decompress if we need
     if ((options & OR_OPTIONS_DONT_DECOMPRESS) == 0) {
       IO::Stream::Ptr s(new IO::MemStream(data.data(), data.size()));
@@ -481,8 +493,7 @@ IfdDir::Ref Cr2File::_locateMainIfd()
       }
       RawDataPtr dData = decomp.decompress();
       if (dData) {
-        Trace(DEBUG1) << "Out size is " << dData->width() << "x"
-                      << dData->height() << "\n";
+        LOGDBG1("Out size is %dx%d\n", dData->width(), dData->height());
         // must re-set the cfaPattern
         dData->setCfaPatternType(data.cfaPattern()->patternType());
         data.swap(*dData);
@@ -490,20 +501,22 @@ IfdDir::Ref Cr2File::_locateMainIfd()
     }
 
     // get the sensor info
-    std::vector<uint16_t> sensorInfo;
     const IfdDir::Ref &_makerNoteIfd = makerNoteIfd();
     e = _makerNoteIfd->getEntry(IFD::MNOTE_CANON_SENSORINFO);
     if (e) {
-      e->getArray(sensorInfo);
-      if (sensorInfo.size() > 8) {
-        uint32_t w = sensorInfo[7] - sensorInfo[5];
-        uint32_t h = sensorInfo[8] - sensorInfo[6];
-        data.setRoi(sensorInfo[5], sensorInfo[6], w, h);
-      }
-      else {
-        LOGWARN("sensorInfo is too small: %lu - skipping.\n",
-                sensorInfo.size());
-      }
+        auto result3 = e->getArray<uint16_t>();
+        if (result3.ok()) {
+            std::vector<uint16_t> sensorInfo = result3.unwrap();
+            if (sensorInfo.size() > 8) {
+                uint32_t w = sensorInfo[7] - sensorInfo[5];
+                uint32_t h = sensorInfo[8] - sensorInfo[6];
+                data.setRoi(sensorInfo[5], sensorInfo[6], w, h);
+            }
+            else {
+                LOGWARN("sensorInfo is too small: %lu - skipping.\n",
+                        sensorInfo.size());
+            }
+        }
     }
 
     return OR_ERROR_NONE;
