@@ -1,7 +1,7 @@
 /*
  * libopenraw - decompressor.cpp
  *
- * Copyright (C) 2007 Hubert Figuiere
+ * Copyright (C) 2007-2016 Hubert Figuiere
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -18,26 +18,16 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-
-#include "io/stream.h"
-#include "decompressor.h"
-
-
+#include "decompressor.hpp"
 
 namespace OpenRaw {
-	namespace Internals {
+namespace Internals {
 
-		Decompressor::Decompressor(IO::Stream *stream,
-															 RawContainer *container)
-			: m_stream(stream), m_container(container)
-		{
-		}
-
-
-		Decompressor::~Decompressor()
-		{
-		}
-
-	}
+Decompressor::Decompressor(IO::Stream *stream, RawContainer *container)
+    : m_stream(stream), m_container(container) {
 }
 
+Decompressor::~Decompressor() {
+}
+}
+}
