@@ -47,6 +47,13 @@ IfdEntry::IfdEntry(uint16_t _id, int16_t _type,
       m_loaded(false), m_dataptr(NULL),
       m_container(_container)
 {
+	auto container_size = m_container.size();
+	auto unit_size = type_unit_size(static_cast<IFD::ExifTagType>(m_type));
+	if ((m_count * unit_size) > static_cast<size_t>(container_size)) {
+		LOGERR("Trying to have %u items in a container of %ld bytes\n",
+			   m_count, container_size);
+		m_count = container_size / unit_size;
+	}
 }
 
 
@@ -62,24 +69,52 @@ namespace {
 template <class T>
 void convert(Internals::IfdEntry* e, std::vector<MetaValue::value_t> & values)
 {
-    std::vector<T> v;
-    e->getArray(v);
-    values.insert(values.end(), v.cbegin(), v.cend());
+    auto result = e->getArray<T>();
+    if (result.ok()) {
+        std::vector<T> v = result.unwrap();
+        values.insert(values.end(), v.cbegin(), v.cend());
+    }
 }
 
 // T is the Ifd primitive type. T2 is the target MetaValue type.
 template <class T, class T2>
 void convert(Internals::IfdEntry* e, std::vector<MetaValue::value_t> & values)
 {
-    std::vector<T> v;
-    e->getArray(v);
-    for(const auto & elem : v) {
-        values.push_back(T2(elem));
+    auto result = e->getArray<T>();
+    if (result.ok()) {
+        std::vector<T> v = result.unwrap();
+        for(const auto & elem : v) {
+            values.push_back(T2(elem));
+        }
     }
 }
 
 }
 
+
+size_t IfdEntry::type_unit_size(IFD::ExifTagType _type)
+{
+	switch(_type) {
+    case IFD::EXIF_FORMAT_BYTE:
+    case IFD::EXIF_FORMAT_SBYTE:
+    case IFD::EXIF_FORMAT_ASCII:
+    case IFD::EXIF_FORMAT_UNDEFINED:
+		return 1;
+    case IFD::EXIF_FORMAT_SHORT:
+    case IFD::EXIF_FORMAT_SSHORT:
+		return 2;
+    case IFD::EXIF_FORMAT_LONG:
+    case IFD::EXIF_FORMAT_SLONG:
+    case IFD::EXIF_FORMAT_FLOAT:
+		return 4;
+    case IFD::EXIF_FORMAT_RATIONAL:
+    case IFD::EXIF_FORMAT_SRATIONAL:
+    case IFD::EXIF_FORMAT_DOUBLE:
+		return 8;
+	}
+
+	return 0;
+}
 MetaValue* IfdEntry::make_meta_value()
 {
     std::vector<MetaValue::value_t> values;
@@ -111,7 +146,7 @@ MetaValue* IfdEntry::make_meta_value()
         break;
     }
     default:
-        Trace(DEBUG1) << "unhandled type " << type() << "\n";
+        LOGDBG1("unhandled type %d\n", type());
         return NULL;
     }
     return new MetaValue(values);
@@ -140,8 +175,8 @@ bool IfdEntry::loadData(size_t unit_size)
 		}
 		_offset += m_container.exifOffsetCorrection();
 		m_dataptr = (uint8_t*)realloc(m_dataptr, data_size);
-		success = (m_container.fetchData(m_dataptr, 
-										 _offset, 
+		success = (m_container.fetchData(m_dataptr,
+										 _offset,
 										 data_size) == data_size);
 	}
 	return success;
@@ -150,7 +185,7 @@ bool IfdEntry::loadData(size_t unit_size)
 uint32_t IfdEntry::getIntegerArrayItem(int idx)
 {
     uint32_t v = 0;
-    
+
     try {
         switch(type())
         {
@@ -176,8 +211,7 @@ uint32_t IfdEntry::getIntegerArrayItem(int idx)
         }
     }
     catch(const std::exception & ex) {
-        Debug::Trace(ERROR) << "Exception raised " << ex.what() 
-                     << " fetch integer value for " << m_id << "\n";
+        LOGERR("Exception raised %s fetch integer value for %d\n", ex.what(), m_id);
     }
 
     return v;
@@ -241,7 +275,9 @@ const size_t IfdTypeTrait<std::string>::size = 1;
   mode:c++
   c-file-style:"stroustrup"
   c-file-offsets:((innamespace . 0))
-  indent-tabs-mode:nil
+  tab-width:4
+  c-basic-offset:4
+  indent-tabs-mode:t
   fill-column:80
   End:
 */
