@@ -1,7 +1,7 @@
 /*
  * libopenraw - ifdfile.cpp
  *
- * Copyright (C) 2006-2017 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  * Copyright (C) 2008 Novell, Inc.
  *
  * This library is free software: you can redistribute it and/or
@@ -47,8 +47,6 @@
 #include "neffile.hpp" // I wonder if this is smart as it break the abstraction.
 #include "unpack.hpp"
 
-using namespace Debug;
-
 namespace OpenRaw {
 
 class MetaValue;
@@ -78,8 +76,7 @@ IfdDir::Ref  IfdFile::_locateExifIfd()
 {
 	const IfdDir::Ref & _mainIfd = mainIfd();
   if (!_mainIfd) {
-    Trace(ERROR) << "IfdFile::_locateExifIfd() "
-      "main IFD not found\n";
+    LOGERR("IfdFile::_locateExifIfd() main IFD not found\n");
     return IfdDir::Ref();
   }
   return _mainIfd->getExifIFD();
@@ -98,45 +95,46 @@ MakerNoteDir::Ref  IfdFile::_locateMakerNoteIfd()
 void IfdFile::_identifyId()
 {
 	const IfdDir::Ref & _mainIfd = mainIfd();
-  if(!_mainIfd) {
-    Trace(ERROR) << "Main IFD not found to identify the file.\n";
+  if (!_mainIfd) {
+    LOGERR("Main IFD not found to identify the file.\n");
     return;
   }
-  std::string make, model;
-  if(_mainIfd->getValue(IFD::EXIF_TAG_MAKE, make) && 
-    _mainIfd->getValue(IFD::EXIF_TAG_MODEL, model)) {
-    _setTypeId(_typeIdFromModel(make, model));
+
+  auto make = _mainIfd->getValue<std::string>(IFD::EXIF_TAG_MAKE);
+  auto model = _mainIfd->getValue<std::string>(IFD::EXIF_TAG_MODEL);
+  if (make.ok() && model.ok()) {
+    _setTypeId(_typeIdFromModel(make.unwrap(), model.unwrap()));
   }
 }
 
 
 
-::or_error IfdFile::_enumThumbnailSizes(std::vector<uint32_t> &list)
+::or_error
+IfdFile::_enumThumbnailSizes(std::vector<uint32_t> &list)
 {
   ::or_error err = OR_ERROR_NONE;
 
-  Trace(DEBUG1) << "_enumThumbnailSizes()\n";
+  LOGDBG1("_enumThumbnailSizes()\n");
   std::vector<IfdDir::Ref> & dirs = m_container->directories();
 
-  Trace(DEBUG1) << "num of dirs " << dirs.size() << "\n";
+  LOGDBG1("num of dirs %lu\n", dirs.size());
   for(auto dir : dirs)
   {
     dir->load();
     or_error ret = _locateThumbnail(dir, list);
-    if (ret == OR_ERROR_NONE)
-    {
-      Trace(DEBUG1) << "Found " << list.back() << " pixels\n";
+    if (ret == OR_ERROR_NONE) {
+      LOGDBG1("Found %u pixels\n", list.back());
     }
-    std::vector<IfdDir::Ref> subdirs;
-    if(dir->getSubIFDs(subdirs)) {
-      Trace(DEBUG1) << "Iterating subdirs\n";
+    auto result = dir->getSubIFDs();
+    if (result.ok()) {
+      std::vector<IfdDir::Ref> subdirs = result.unwrap();
+      LOGDBG1("Iterating subdirs\n");
       for(auto dir2 : subdirs)
       {
         dir2->load();
         ret = _locateThumbnail(dir2, list);
-        if (ret == OR_ERROR_NONE)
-        {
-          Trace(DEBUG1) << "Found " << list.back() << " pixels\n";
+        if (ret == OR_ERROR_NONE) {
+          LOGDBG1("Found %u pixels\n", list.back());
         }
       }
     }
@@ -152,17 +150,13 @@ void IfdFile::_identifyId()
                                      std::vector<uint32_t> &list)
 {
   ::or_error ret = OR_ERROR_NOT_FOUND;
-  bool got_it;
-  uint32_t x = 0;
-  uint32_t y = 0;
   ::or_data_type _type = OR_DATA_TYPE_NONE;
   uint32_t subtype = 0;
 
-  Trace(DEBUG1) << "_locateThumbnail\n";
+  LOGDBG1("_locateThumbnail\n");
 
-  got_it = dir->getValue(IFD::EXIF_TAG_NEW_SUBFILE_TYPE, subtype);
-  Trace(DEBUG1) << "subtype " << subtype  << "\n";
-  if(!got_it) {
+  auto result = dir->getValue<uint32_t>(IFD::EXIF_TAG_NEW_SUBFILE_TYPE);
+  if (result.empty()) {
     if(!m_cfaIfd) {
       m_cfaIfd = _locateCfaIfd();
     }
@@ -172,38 +166,37 @@ void IfdFile::_identifyId()
     else {
       subtype = 1;
     }
+  } else {
+    subtype = result.unwrap();
   }
+  LOGDBG1("subtype %u\n", subtype);
   if (subtype == 1) {
 
-    uint16_t photom_int = 0;
-    got_it = dir->getValue(IFD::EXIF_TAG_PHOTOMETRIC_INTERPRETATION,
-                           photom_int);
+    uint16_t photom_int =
+      dir->getValue<uint16_t>(IFD::EXIF_TAG_PHOTOMETRIC_INTERPRETATION).unwrap_or(IFD::EV_PI_RGB);
 
-    if (got_it) {
-      Trace(DEBUG1) << "photometric int " << photom_int  << "\n";
-    }
-    // photometric interpretation is RGB by default
-    else {
-      photom_int = IFD::EV_PI_RGB;
-      Trace(DEBUG1) << "assume photometric int is RGB\n";
-    }
+    uint32_t x = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH).unwrap_or(0);
+    uint32_t y = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH).unwrap_or(0);
 
-    got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH, x);
-    got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH, y);
-
-    uint16_t compression = 0;
-    got_it = dir->getValue(IFD::EXIF_TAG_COMPRESSION, compression);
+    uint16_t compression = dir->getValue<uint16_t>(IFD::EXIF_TAG_COMPRESSION).unwrap_or(0);
 
     uint32_t offset = 0;
-    uint32_t byte_count = 0;
-    got_it = dir->getValue(IFD::EXIF_TAG_STRIP_BYTE_COUNTS, byte_count);
-    got_it = dir->getValue(IFD::EXIF_TAG_STRIP_OFFSETS, offset);
+    uint32_t byte_count = dir->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_BYTE_COUNTS).unwrap_or(0);
+
+    result = dir->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_OFFSETS);
+    bool got_it = result.ok();
+    if (result.ok()) {
+      offset = result.unwrap();
+    }
     if (!got_it || (compression == 6) || (compression == 7)) {
-      if(!got_it) {
-        got_it = dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH,
-                               byte_count);
-        got_it = dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT,
-                               offset);
+      if (!got_it) {
+        byte_count =
+          dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH).unwrap_or(0);
+        result = dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT);
+        got_it = result.ok();
+        if (got_it) {
+          offset = result.unwrap();
+        }
       }
       if (got_it) {
         // workaround for CR2 files where 8RGB data is marked
@@ -213,7 +206,7 @@ void IfdFile::_identifyId()
             //_type = OR_DATA_TYPE_PIXMAP_8RGB;
             _type = OR_DATA_TYPE_NONE;
             // See bug 72270
-            Trace(DEBUG1) << "8RGB as JPEG. Will ignore.\n";
+            LOGDBG1("8RGB as JPEG. Will ignore.\n");
             ret = OR_ERROR_INVALID_FORMAT;
           }
           else {
@@ -222,54 +215,49 @@ void IfdFile::_identifyId()
         }
         else {
           _type = OR_DATA_TYPE_JPEG;
-          Trace(DEBUG1) << "looking for JPEG at " << offset << "\n";
+          LOGDBG1("looking for JPEG at %u\n", offset);
           if (x == 0 || y == 0) {
             IO::Stream::Ptr s(std::make_shared<IO::StreamClone>(
                                 m_io, offset));
             std::unique_ptr<JfifContainer> jfif(new JfifContainer(s, 0));
             if (jfif->getDimensions(x,y)) {
-              Trace(DEBUG1) << "JPEG dimensions x=" << x
-                            << " y=" << y << "\n";
+              LOGDBG1("JPEG dimensions x=%u y=%u\n", x, y);
             }
             else {
               _type = OR_DATA_TYPE_NONE;
-              Trace(WARNING) << "Couldn't get JPEG "
-                "dimensions.\n";
+              LOGWARN("Couldn't get JPEG dimensions.\n");
             }
           }
           else {
-            Trace(DEBUG1) << "JPEG (supposed) dimensions x=" << x
-                          << " y=" << y << "\n";
+            LOGDBG1("JPEG (supposed) dimensions x=%u y=%u\n", x, y);
           }
         }
 
       }
     }
     else if (photom_int == IFD::EV_PI_YCBCR) {
-      Trace(WARNING) << "Unsupported YCbCr photometric "
-        "interpretation in non JPEG.\n";
+      LOGWARN("Unsupported YCbCr photometric interpretation in non JPEG.\n");
       ret = OR_ERROR_INVALID_FORMAT;
     }
     else {
-      Trace(DEBUG1) << "found strip offsets\n";
+      LOGDBG1("found strip offsets\n");
       if (x != 0 && y != 0) {
         // See bug 72270 - some CR2 have 16 bpc RGB thumbnails.
         // by default it is RGB8. Unless stated otherwise.
         bool isRGB8 = true;
-        try {
-          IfdEntry::Ref entry = dir->getEntry(IFD::EXIF_TAG_BITS_PER_SAMPLE);
-          std::vector<uint16_t> arr;
-          entry->getArray(arr);
+        IfdEntry::Ref entry = dir->getEntry(IFD::EXIF_TAG_BITS_PER_SAMPLE);
+        auto result2 = entry->getArray<uint16_t>();
+        if (result2.ok()) {
+          std::vector<uint16_t> arr = result2.unwrap();
           for(auto bpc : arr) {
             isRGB8 = (bpc == 8);
             if (!isRGB8) {
-              Trace(DEBUG1) << "bpc != 8, not RGB8 " << bpc << "\n";
+              LOGDBG1("bpc != 8, not RGB8 %u\n", bpc);
               break;
             }
           }
-        }
-        catch(const std::exception & e) {
-          Trace(DEBUG1) << "Exception getting BPS " << e.what() << "\n";
+        } else {
+          LOGDBG1("Error getting BPS\n");
         }
         if (isRGB8) {
           _type = OR_DATA_TYPE_PIXMAP_8RGB;
@@ -296,17 +284,15 @@ RawContainer* IfdFile::getContainer() const
 
 uint32_t IfdFile::_getJpegThumbnailOffset(const IfdDir::Ref & dir, uint32_t & byte_length)
 {
-  uint32_t offset = 0;
-  bool got_it = dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH, byte_length);
-  if(got_it) {
-    got_it = dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT, offset);
+  auto result = dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH);
+  if (result.ok()) {
+    byte_length = result.unwrap();
+    return dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT).unwrap_or(0);
   }
-  else {
-    // some case it is STRIP_OFFSETS for JPEG
-    got_it = dir->getValue(IFD::EXIF_TAG_STRIP_OFFSETS, offset);
-    got_it = dir->getValue(IFD::EXIF_TAG_STRIP_BYTE_COUNTS, byte_length);
-  }
-  return offset;
+
+  // some case it is STRIP_OFFSETS for JPEG
+  byte_length = dir->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_BYTE_COUNTS).unwrap_or(0);
+  return dir->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_OFFSETS).unwrap_or(0);
 }
 
 
@@ -322,11 +308,10 @@ MetaValue *IfdFile::_getMetaValue(int32_t meta_index)
     ifd = exifIfd();
   }
   else {
-    Trace(ERROR) << "Unknown Meta Namespace\n";
+    LOGERR("Unknown Meta Namespace\n");
   }
   if(ifd) {
-    Trace(DEBUG1) << "Meta value for "
-                  << META_NS_MASKOUT(meta_index) << "\n";
+    LOGDBG1("Meta value for %u\n", META_NS_MASKOUT(meta_index));
 
     IfdEntry::Ref e = ifd->getEntry(META_NS_MASKOUT(meta_index));
     if(e) {
@@ -338,9 +323,9 @@ MetaValue *IfdFile::_getMetaValue(int32_t meta_index)
 
 /** by default we don't translate the compression
  */
-uint32_t IfdFile::_translateCompressionType(IFD::TiffCompress tiffCompression)
+uint32_t IfdFile::_translateCompressionType(IFD::TiffCompress tiff_compression)
 {
-	return (uint32_t)tiffCompression;
+	return (uint32_t)tiff_compression;
 }
 
 
@@ -388,51 +373,40 @@ _convertArrayToCfaPattern(const std::vector<uint8_t> &cfaPattern)
 {
   ::or_cfa_pattern cfa_pattern = OR_CFA_PATTERN_NON_RGB22;
   if(cfaPattern.size() != 4) {
-    Trace(WARNING) << "Unsupported bayer pattern\n";
+    LOGWARN("Unsupported bayer pattern\n");
   }
   else {
-    Trace(DEBUG2) << "patter is = " << cfaPattern[0] << ", "
-                  << cfaPattern[1] << ", " << cfaPattern[2]
-                  << ", " << cfaPattern[3] << "\n";
+    LOGDBG2("pattern is = %d, %d, %d, %d\n", cfaPattern[0],
+            cfaPattern[1], cfaPattern[2], cfaPattern[3]);
     switch(cfaPattern[0]) {
     case IFD::CFA_RED:
-      switch(cfaPattern[1]) {
-      case IFD::CFA_GREEN:
-        if((cfaPattern[2] == IFD::CFA_GREEN)
-           && (cfaPattern[3] == IFD::CFA_BLUE))
-        {
-          cfa_pattern = OR_CFA_PATTERN_RGGB;
-        }
-        break;
+      if ((cfaPattern[1] == IFD::CFA_GREEN)
+          && (cfaPattern[2] == IFD::CFA_GREEN)
+          && (cfaPattern[3] == IFD::CFA_BLUE)) {
+        cfa_pattern = OR_CFA_PATTERN_RGGB;
       }
       break;
     case IFD::CFA_GREEN:
       switch(cfaPattern[1]) {
       case IFD::CFA_RED:
-        if((cfaPattern[2] == 2)
-           && (cfaPattern[3] == IFD::CFA_GREEN))
-        {
+        if ((cfaPattern[2] == IFD::CFA_BLUE)
+            && (cfaPattern[3] == IFD::CFA_GREEN)) {
           cfa_pattern = OR_CFA_PATTERN_GRBG;
         }
         break;
       case 2:
-        if((cfaPattern[2] == IFD::CFA_RED)
-           && (cfaPattern[3] == IFD::CFA_GREEN))
-        {
+        if ((cfaPattern[2] == IFD::CFA_RED)
+            && (cfaPattern[3] == IFD::CFA_GREEN)) {
           cfa_pattern = OR_CFA_PATTERN_GBRG;
         }
         break;
       }
       break;
     case IFD::CFA_BLUE:
-      switch(cfaPattern[1]) {
-      case IFD::CFA_GREEN:
-        if((cfaPattern[2] == IFD::CFA_GREEN)
-           && (cfaPattern[3] == IFD::CFA_RED))
-        {
-          cfa_pattern = OR_CFA_PATTERN_BGGR;
-        }
-        break;
+      if ((cfaPattern[1] ==IFD::CFA_GREEN)
+          && (cfaPattern[2] == IFD::CFA_GREEN)
+          && (cfaPattern[3] == IFD::CFA_RED)) {
+        cfa_pattern = OR_CFA_PATTERN_BGGR;
       }
       break;
     }
@@ -468,13 +442,13 @@ _convertArrayToCfaPattern(const std::vector<uint8_t> &cfaPattern)
 /** convert the CFA Pattern as stored in the entry */
 ::or_cfa_pattern _convertCfaPattern(const IfdEntry::Ref & e)
 {
-  std::vector<uint8_t> cfaPattern;
   ::or_cfa_pattern cfa_pattern = OR_CFA_PATTERN_NONE;
 
-  e->getArray(cfaPattern);
-  if(!cfaPattern.empty()) {
-    cfa_pattern = _convertArrayToCfaPattern(cfaPattern);
+  auto result = e->getArray<uint8_t>();
+  if (result.ok()) {
+    cfa_pattern = _convertArrayToCfaPattern(result.unwrap());
   }
+
   return cfa_pattern;
 }
 
@@ -485,7 +459,7 @@ _convertArrayToCfaPattern(const std::vector<uint8_t> &cfaPattern)
  */
 static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
 {
-  Trace(DEBUG1) << __FUNCTION__ << "\n";
+  LOGDBG1("%s\n", __FUNCTION__);
   ::or_cfa_pattern cfa_pattern = OR_CFA_PATTERN_NONE;
   try {
     IfdEntry::Ref e = dir->getEntry(IFD::EXIF_TAG_CFA_PATTERN);
@@ -501,7 +475,7 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
   }
   catch(...)
   {
-    Trace(ERROR) << "Exception in _getCfaPattern().\n";
+    LOGERR("Exception in _getCfaPattern().\n");
   }
   return cfa_pattern;
 }
@@ -513,7 +487,7 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
 {
   ::or_error ret = OR_ERROR_NONE;
   const IfdDir::Ref & _cfaIfd = cfaIfd();
-  Trace(DEBUG1) << "_getRawData()\n";
+  LOGDBG1("_getRawData()\n");
 
   if(_cfaIfd) {
     ret = _getRawDataFromDir(data, _cfaIfd);
@@ -538,87 +512,89 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
 {
   ::or_error ret = OR_ERROR_NONE;
 
-  uint16_t bpc = 0;
   uint32_t offset = 0;
   uint32_t byte_length = 0;
-  bool got_it;
-  uint32_t x, y;
-  x = 0;
-  y = 0;
 
   if(!dir) {
-    Trace(ERROR) << "dir is NULL\n";
+    LOGERR("dir is NULL\n");
     return OR_ERROR_NOT_FOUND;
   }
-  got_it = dir->getValue(IFD::EXIF_TAG_BITS_PER_SAMPLE, bpc);
-  if(!got_it) {
-    Trace(ERROR) << "unable to guess Bits per sample\n";
+  auto result = dir->getValue<uint16_t>(IFD::EXIF_TAG_BITS_PER_SAMPLE);
+  if(result.empty()) {
+    LOGERR("unable to guess Bits per sample\n");
   }
+  uint16_t bpc = result.unwrap_or(0);
 
-  got_it = dir->getValue(IFD::EXIF_TAG_STRIP_OFFSETS, offset);
-  if(got_it) {
+  auto result2 = dir->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_OFFSETS);
+  if(result2.ok()) {
+    offset = result2.unwrap();
     IfdEntry::Ref e = dir->getEntry(IFD::EXIF_TAG_STRIP_BYTE_COUNTS);
     if(!e) {
-      Trace(DEBUG1) << "byte len not found\n";
+      LOGDBG1("byte len not found\n");
       return OR_ERROR_NOT_FOUND;
     }
-    std::vector<uint32_t> counts;
-    e->getArray(counts);
-    Trace(DEBUG1) << "counting tiles\n";
-    byte_length = std::accumulate(counts.cbegin(), counts.cend(), 0);
+    auto result3 = e->getArray<uint32_t>();
+    if (result3.ok()) {
+      std::vector<uint32_t> counts = result3.unwrap();
+      LOGDBG1("counting tiles\n");
+      byte_length = std::accumulate(counts.cbegin(), counts.cend(), 0);
+    }
   }
   else {
     // the tile are individual JPEGS....
     // TODO extract all of them.
     IfdEntry::Ref e = dir->getEntry(IFD::TIFF_TAG_TILE_OFFSETS);
     if(!e) {
-      Trace(DEBUG1) << "tile offsets empty\n";
+      LOGDBG1("tile offsets empty\n");
       return OR_ERROR_NOT_FOUND;
     }
-    std::vector<uint32_t> offsets;
-    e->getArray(offsets);
-    if(offsets.size() == 0) {
-      Trace(DEBUG1) << "tile offsets not found\n";
+    auto result3 = e->getArray<uint32_t>();
+    if (result3.empty()) {
+      LOGDBG1("tile offsets not found\n");
       return OR_ERROR_NOT_FOUND;
     }
+    std::vector<uint32_t> offsets = result3.unwrap();
     offset = offsets[0];
     e = dir->getEntry(IFD::TIFF_TAG_TILE_BYTECOUNTS);
     if(!e) {
-      Trace(DEBUG1) << "tile byte counts not found\n";
+      LOGDBG1("tile byte counts not found\n");
       return OR_ERROR_NOT_FOUND;
     }
-    std::vector<uint32_t> counts;
-    e->getArray(counts);
-    Trace(DEBUG1) << "counting tiles\n";
-    byte_length = std::accumulate(counts.cbegin(), counts.cend(), 0);
-  }
-  got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH, x);
-  if(!got_it) {
-    Trace(DEBUG1) << "X not found\n";
-    return OR_ERROR_NOT_FOUND;
-  }
-  got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH, y);
-  if(!got_it) {
-    Trace(DEBUG1) << "Y not found\n";
-    return OR_ERROR_NOT_FOUND;
+    result3 = e->getArray<uint32_t>();
+    if (result3.ok()) {
+      std::vector<uint32_t> counts = result3.unwrap();
+      LOGDBG1("counting tiles\n");
+      byte_length = std::accumulate(counts.cbegin(), counts.cend(), 0);
+    }
   }
 
-  uint32_t photo_int = 0;
-  got_it = dir->getIntegerValue(IFD::EXIF_TAG_PHOTOMETRIC_INTERPRETATION,
-                                photo_int);
-  if(!got_it) {
-    // Default is CFA.
-    photo_int = IFD::EV_PI_CFA;
+  result2 = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH);
+  if(result2.empty()) {
+    LOGDBG1("X not found\n");
+    return OR_ERROR_NOT_FOUND;
   }
+  uint32_t x = result2.unwrap();
 
-  uint16_t tiffCompression = 0;
-  got_it = dir->getValue(IFD::EXIF_TAG_COMPRESSION, tiffCompression);
-  if(!got_it) {
-    Trace(DEBUG1) << "Compression type not found\n";
+  result2 = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH);
+  if(result2.empty()) {
+    LOGDBG1("Y not found\n");
+    return OR_ERROR_NOT_FOUND;
   }
+  uint32_t y = result2.unwrap();
+
+  uint32_t photo_int
+    = dir->getIntegerValue(IFD::EXIF_TAG_PHOTOMETRIC_INTERPRETATION)
+    .unwrap_or(IFD::EV_PI_CFA);
+
   BitmapData::DataType data_type = OR_DATA_TYPE_NONE;
 
-	uint32_t compression = _translateCompressionType((IFD::TiffCompress)tiffCompression);
+  result = dir->getValue<uint16_t>(IFD::EXIF_TAG_COMPRESSION);
+  if(result.empty()) {
+    LOGDBG1("Compression type not found\n");
+  }
+	uint32_t compression = _translateCompressionType(
+    static_cast<IFD::TiffCompress>(result.unwrap_or(0)));
+
   switch(compression)
   {
   case IFD::COMPRESS_NONE:
@@ -630,7 +606,7 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
   case IFD::COMPRESS_NIKON_QUANTIZED:
     // must check whether it is really compressed
     // only for D100
-    if( !NefFile::isCompressed(*m_container, offset) ) {
+    if (!NefFile::isCompressed(*m_container, offset)) {
       compression = IFD::COMPRESS_NIKON_PACK;
       data_type = OR_DATA_TYPE_RAW;
       // this is a hack. we should check if
@@ -661,8 +637,7 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
   if((bpc == 12 || bpc == 14) && (compression == IFD::COMPRESS_NONE)
      && (byte_length == (x * y * 2))) {
     // We turn this to a 16-bits per sample. MSB are 0
-    Trace(DEBUG1) << "setting bpc from " << bpc
-                  << " to 16\n";
+    LOGDBG1("setting bpc from %u to 16\n", bpc);
     bpc = 16;
   }
   if((bpc == 16) || (data_type == OR_DATA_TYPE_COMPRESSED_RAW)) {
@@ -670,15 +645,15 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
     size_t real_size = m_container->fetchData(p, offset,
                                               byte_length);
     if (real_size < byte_length) {
-      Trace(WARNING) << "Size mismatch for data: ignoring.\n";
+      LOGWARN("Size mismatch for data: ignoring.\n");
     }
   }
   else if((bpc == 12) || (bpc == 8)) {
     ret = _unpackData(bpc, compression, data, x, y, offset, byte_length);
-    Trace(DEBUG1) << "unpack result " << ret << "\n";
+    LOGDBG1("unpack result %d\n", ret);
   }
   else {
-    Trace(ERROR) << "Unsupported bpc " << bpc << "\n";
+    LOGERR("Unsupported bpc %u\n", bpc);
     return OR_ERROR_INVALID_FORMAT;
   }
   data.setCfaPatternType(cfa_pattern);
@@ -696,21 +671,22 @@ static ::or_cfa_pattern _getCfaPattern(const IfdDir::Ref & dir)
 }
 
 
-::or_error IfdFile::_unpackData(uint16_t bpc, uint32_t compression, RawData & data, uint32_t x, uint32_t y, uint32_t offset, uint32_t byte_length)
+::or_error
+IfdFile::_unpackData(uint16_t bpc, uint32_t compression, RawData & data,
+                     uint32_t x, uint32_t y, uint32_t offset, uint32_t byte_length)
 {
   ::or_error ret = OR_ERROR_NONE;
   size_t fetched = 0;
   uint32_t current_offset = offset;
   Unpack unpack(x, compression);
   const size_t blocksize = (bpc == 8 ? x : unpack.block_size());
-  Trace(DEBUG1) << "Block size = " << blocksize << "\n";
-  Trace(DEBUG1) << "dimensions (x, y) " << x << ", "
-                << y << "\n";
+  LOGDBG1("Block size = %lu\n", blocksize);
+  LOGDBG1("dimensions (x, y) %u, %u\n", x, y);
   std::unique_ptr<uint8_t[]> block(new uint8_t[blocksize]);
   size_t outsize = x * y * 2;
   uint8_t * outdata = (uint8_t*)data.allocData(outsize);
   size_t got;
-  Trace(DEBUG1) << "offset of RAW data = " << current_offset << "\n";
+  LOGDBG1("offset of RAW data = %u\n", current_offset);
   do {
     got = m_container->fetchData (block.get(),
                                   current_offset, blocksize);
