@@ -1,7 +1,7 @@
 /*
- * libopenraw - iostream.h
+ * libopenraw - stream.cpp
  *
- * Copyright (C) 2006-2007 Hubert Figuière
+ * Copyright (C) 2006-2016 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -19,33 +19,45 @@
  */
 
 
-#include "stream.h"
-#include "exception.h"
+#include <libopenraw/consts.h>
+
+#include "stream.hpp"
+#include "exception.hpp"
 
 namespace OpenRaw {
-	namespace IO {
-		
-		Stream::Stream(const char *filename)
-			: m_fileName(filename),
-				m_error(OR_ERROR_NONE)
-		{
-		}
+namespace IO {
 
-		Stream::~Stream()
-		{
-		}
-
-		uint8_t Stream::readByte() throw(Internals::IOException)
-		{
-			uint8_t theByte;
-			int r = read(&theByte, 1);
-			if (r != 1) {
-				// TODO add the error code
-				throw Internals::IOException("Stream::readByte() failed.");
-			}
-			return theByte;
-		}
-	}
+Stream::Stream(const char *filename)
+  : m_fileName(filename),
+    m_error(OR_ERROR_NONE)
+{
 }
 
+Stream::~Stream()
+{
+}
 
+uint8_t Stream::readByte() noexcept(false)
+{
+  uint8_t theByte;
+  int r = read(&theByte, 1);
+  if (r != 1) {
+    // TODO add the error code
+    throw Internals::IOException("Stream::readByte() failed.");
+  }
+  return theByte;
+}
+
+}
+}
+/*
+  Local Variables:
+  mode:c++
+  c-file-style:"stroustrup"
+  c-file-offsets:((innamespace . 0))
+  tab-width:2
+  c-basic-offset:2
+  indent-tabs-mode:nil
+  fill-column:80
+  End:
+*/
