@@ -1,7 +1,7 @@
 /*
  * libopenraw - jfifcontainer.cpp
  *
- * Copyright (C) 2006-2016 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -116,7 +116,7 @@ bool JfifContainer::getDimensions(uint32_t &x, uint32_t &y)
 {
   if(!m_headerLoaded) {
     if (_loadHeader() == 0) {
-      Trace(DEBUG1) << "load header failed\n";
+      LOGDBG1("load header failed\n");
       return false;
     }
   }
@@ -130,7 +130,7 @@ bool JfifContainer::getDecompressedData(BitmapData &data)
 {
   if(!m_headerLoaded) {
     if (_loadHeader() == 0) {
-      Trace(DEBUG1) << "load header failed\n";
+      LOGDBG1("load header failed\n");
       return false;
     }
   }
@@ -230,10 +230,10 @@ std::unique_ptr<IfdFileContainer> & JfifContainer::ifdContainer()
   if(!m_ifd) {
     m_file->seek(0, SEEK_SET);
 
-    uint16_t marker;
-    readUInt16(m_file, marker); // SOI
-    readUInt16(m_file, marker); // APP0
-    readUInt16(m_file, marker); // ignore
+    // XXX check results and bail.
+    auto result = readUInt16(m_file); // SOI
+    result = readUInt16(m_file); // APP0
+    result = readUInt16(m_file); // ignore
 
     char delim[7];
     delim[6] = 0;
