@@ -243,7 +243,7 @@ RafFile::~RafFile()
 
     JfifContainer *jpegPreview = m_container->getJpegPreview();
     if (!jpegPreview) {
-        return ret;
+        return OR_ERROR_NOT_FOUND;
     }
 
     uint32_t x, y;
@@ -261,30 +261,28 @@ RafFile::~RafFile()
         return ret;
     }
 
-    bool got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH, x);
-
-    if (got_it) {
-        got_it = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH, y);
+    auto result = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_WIDTH);
+    if (result.ok()) {
+        x = result.unwrap();
+        result = dir->getIntegerValue(IFD::EXIF_TAG_IMAGE_LENGTH);
+        y = result.unwrap_or(0);
     }
 
-    if (!got_it) {
-        uint32_t jpeg_offset = 0;
-        uint32_t jpeg_size = 0;
-        got_it =
-            dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT, jpeg_offset);
-
-        if (!got_it) {
+    if (result.empty()) {
+        result =
+            dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT);
+        if (result.empty()) {
             return ret;
         }
+        uint32_t jpeg_offset = result.unwrap();
 
-        jpeg_offset += 12; // magic number. uh?
+        jpeg_offset += 12; // XXX magic number. eh?
                            // I need to re-read the Exif spec.
-        got_it = dir->getValue(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH,
-                               jpeg_size);
-
-        if (!got_it) {
+        result = dir->getValue<uint32_t>(IFD::EXIF_TAG_JPEG_INTERCHANGE_FORMAT_LENGTH);
+        if (result.empty()) {
             return ret;
         }
+        uint32_t jpeg_size = result.unwrap();
 
         IO::Stream::Ptr s(std::make_shared<IO::StreamClone>(jpegPreview->file(),
                                                             jpeg_offset));
@@ -383,9 +381,8 @@ RafFile::isXTrans(RawFile::TypeId type) const
     uint32_t datalen = (is_compressed ? byte_size : finaldatalen);
     void *buf = data.allocData(finaldatalen);
 
-    Debug::Trace(DEBUG2) << "byte_size = " << byte_size
-                         << " finaldatalen = " << finaldatalen
-                         << " compressed = " << compressed << "\n";
+    LOGDBG2("byte_size = %lu finaldatalen = %u compressed = %u", byte_size,
+            finaldatalen, compressed);
 
     ret = OR_ERROR_NONE;
 
@@ -397,29 +394,21 @@ RafFile::isXTrans(RawFile::TypeId type) const
         size_t outsize = finaldatalen;
         size_t got;
         do {
-            //      Debug::Trace(DEBUG2) << "fatchData @offset " << offset <<
-            //      "\n";
             got = m_container->fetchData(block.get(), offset, blocksize);
             fetched += got;
             offset += got;
-            //      Debug::Trace(DEBUG2) << "got " << got << "\n";
+
             if (got) {
                 size_t out;
                 or_error err = unpack.unpack_be12to16(outdata, outsize,
                                                       block.get(), got, out);
                 outdata += out;
                 outsize -= out;
-                //        Debug::Trace(DEBUG2) << "unpacked " << out
-                //                             << " bytes from " << got << "\n";
                 if (err != OR_ERROR_NONE) {
-                    Debug::Trace(DEBUG2) << "error is " << err << "\n";
+                    LOGDBG2("error is %d\n", static_cast<int>(err));
                     ret = err;
                     break;
                 }
-                //        Debug::Trace(DEBUG2) << "got = " << got
-                //                             << " fetched = " << fetched
-                //                             << " datalen = " << datalen <<
-                //                             "\n";
             }
         } while ((got != 0) && (fetched < datalen));
     } else {
