@@ -1,8 +1,8 @@
-/* -*- Mode: C++; c-basic-offset:4; tab-width:4; indent-tab-mode:nil -*- */
+/* -*- Mode: C++; c-basic-offset:4; tab-width:4; indent-tabs-mode:nil -*- */
 /*
  * libopenraw - rawcontainer.cpp
  *
- * Copyright (C) 2006-2017 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -55,49 +55,47 @@ bool RawContainer::skip(off_t offset)
   return true;
 }
 
-bool RawContainer::readInt8(const IO::Stream::Ptr &f, int8_t & v)
+Option<int8_t>
+RawContainer::readInt8(const IO::Stream::Ptr &f)
 {
   unsigned char buf;
   int s = f->read(&buf, 1);
   if (s != 1) {
-    return false;
+    return Option<int8_t>();
   }
-  v = buf;
-  return true;
+  return Option<int8_t>(buf);
 }
 
-bool RawContainer::readUInt8(const IO::Stream::Ptr &f, uint8_t & v)
+Option<uint8_t>
+RawContainer::readUInt8(const IO::Stream::Ptr &f)
 {
   unsigned char buf;
   int s = f->read(&buf, 1);
   if (s != 1) {
-    return false;
+    return Option<uint8_t>();
   }
-  v = buf;
-  return true;
+  return Option<uint8_t>(buf);
 }
 
-bool 
-RawContainer::readInt16(const IO::Stream::Ptr &f, int16_t & v)
+Option<int16_t>
+RawContainer::readInt16(const IO::Stream::Ptr &f)
 {
   if (m_endian == ENDIAN_NULL) {
-    
-    Trace(ERROR) << "null endian\n";
-    
-    return false;
+
+    LOGERR("null endian\n");
+
+    return Option<int16_t>();
   }
   unsigned char buf[2];
   int s = f->read(buf, 2);
   if (s != 2) {
-    return false;
+    return Option<int16_t>();
   }
   if (m_endian == ENDIAN_LITTLE) {
-    v = EL16(buf);
+    return Option<int16_t>(EL16(buf));
+  } else {
+    return Option<int16_t>(BE16(buf));
   }
-  else {
-    v = BE16(buf);
-  }
-  return true;
 }
 
 
@@ -136,93 +134,86 @@ RawContainer::readUInt16Array(const IO::Stream::Ptr &f, std::vector<uint16_t> &
 }
 
 
-bool 
-RawContainer::readInt32(const IO::Stream::Ptr &f, int32_t & v)
+Option<int32_t>
+RawContainer::readInt32(const IO::Stream::Ptr &f)
 {
   if (m_endian == ENDIAN_NULL) {
-    
-    Trace(ERROR) << "null endian\n";
-    
-    return false;
+    LOGERR("null endian\n");
+    return Option<int32_t>();
   }
   unsigned char buf[4];
   int s = f->read(buf, 4);
   if (s != 4) {
-    Trace(ERROR) << "read " << s << " bytes\n";
-    return false;
+    LOGERR("read %d bytes\n", s);
+    return Option<int32_t>();
   }
 
   if (m_endian == ENDIAN_LITTLE) {
-    v = EL32(buf);
+    return Option<int32_t>(EL32(buf));
+  } else {
+    return Option<int32_t>(BE32(buf));
   }
-  else {
-    v = BE32(buf);
-  }
-
-  return true;
 }
 
 
-bool
-RawContainer::readUInt16(const IO::Stream::Ptr &f, uint16_t & v)
+Option<uint16_t>
+RawContainer::readUInt16(const IO::Stream::Ptr &f)
 {
   if (m_endian == ENDIAN_NULL) {
 
-    Trace(ERROR) << "null endian\n";
+    LOGERR("null endian\n");
 
-    return false;
+    return Option<uint16_t>();
   }
   unsigned char buf[2];
   int s = f->read(buf, 2);
   if (s != 2) {
-    return false;
+    return Option<uint16_t>();
   }
   if (m_endian == ENDIAN_LITTLE) {
-    v = EL16(buf);
+    return Option<uint16_t>(EL16(buf));
+  } else {
+    return Option<uint16_t>(BE16(buf));
   }
-  else {
-    v = BE16(buf);
-  }
-  return true;
 }
 
 
-bool
-RawContainer::readUInt32(const IO::Stream::Ptr &f, uint32_t & v)
+Option<uint32_t>
+RawContainer::readUInt32(const IO::Stream::Ptr &f)
 {
   if (m_endian == ENDIAN_NULL) {
+    LOGERR("null endian\n");
 
-    Trace(ERROR) << "null endian\n";
-
-    return false;
+    return Option<uint32_t>();
   }
   unsigned char buf[4];
   int s = f->read(buf, 4);
   if (s != 4) {
-    return false;
+    return Option<uint32_t>();
   }
 
   if (m_endian == ENDIAN_LITTLE) {
-    v = EL32(buf);
+    return Option<uint32_t>(EL32(buf));
+  } else {
+    return Option<uint32_t>(BE32(buf));
   }
-  else {
-    v = BE32(buf);
-  }
-
-  return true;
 }
 
-
-size_t 
+size_t
 RawContainer::fetchData(void *buf, off_t _offset,
                         size_t buf_size)
 {
-  size_t s;
+  size_t s = 0;
   m_file->seek(_offset, SEEK_SET);
   s = m_file->read(buf, buf_size);
   return s;
 }
 
+off_t
+RawContainer::size() const
+{
+  return m_file->filesize();
+}
 
 }
 }
