@@ -1,7 +1,8 @@
+/* -*- Mode: C++ -*- */
 /*
  * libopenraw - testsuitehandler.h
  *
- * Copyright (C) 2008 Hubert Figuiere
+ * Copyright (C) 2008-2015 Hubert Figuiere
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -18,41 +19,37 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-
-
 #ifndef _TEST_TESTSUITEHANDLER_H_
 #define _TEST_TESTSUITEHANDLER_H_
 
+#include <stdint.h>
+#include <string>
+
 #include "xmlhandler.h"
 #include "testsuite.h"
 
-class TestContext
-	: public xml::Context
-{
+class TestContext : public xml::Context {
 public:
-	TestContext(const xml::HandlerPtr & handler, TestSuite * ts,
-                Test::Ptr test);
+    TestContext(const xml::HandlerPtr& handler, TestSuite* ts, Test::Ptr&& test);
+
+    xml::ContextPtr startElement(int32_t element) override;
+    void endElement(int32_t element) override;
 
-	xml::ContextPtr startElement(int32_t element);
-	void endElement(int32_t element);
 private:
-	TestSuite * m_ts;
-	Test::Ptr m_test;
-	bool m_results;
+    TestSuite* m_ts;
+    Test::Ptr m_test;
+    bool m_results;
 };
 
-
-class TestSuiteHandler
-	: public xml::Handler
-{
+class TestSuiteHandler : public xml::Handler {
 public:
-	TestSuiteHandler(const std::string & filename, TestSuite * ts);
+    TestSuiteHandler(const std::string& filename, TestSuite* ts);
+
+    virtual xml::ContextPtr startElement(int32_t element) override;
+    virtual void endElement(int32_t element) override;
 
-	virtual xml::ContextPtr startElement(int32_t element);
-    virtual void endElement(int32_t element);
 private:
-	TestSuite * m_ts;
-    Test::Ptr   m_newtest;
+    TestSuite* m_ts;
 };
 
 #endif
